@@ -18,6 +18,7 @@ from warnings import warn
 from pyiron_base.project.path import ProjectPath
 from pyiron_base.database.filetable import FileTable
 from pyiron_base.settings.generic import Settings
+from pyiron_base.database.manager import DatabaseManager
 from pyiron_base.settings.publications import list_publications
 from pyiron_base.database.performance import get_database_statistics
 from pyiron_base.database.jobtable import (
@@ -34,6 +35,7 @@ from pyiron_base.database.jobtable import (
 from pyiron_base.settings.logger import set_logging_level
 from pyiron_base.generic.hdfio import ProjectHDFio
 from pyiron_base.generic.filedata import load_file
+from pyiron_base.generic.util import deprecate
 from pyiron_base.interfaces.has_groups import HasGroups
 from pyiron_base.job.jobtype import JobType, JobTypeChoice, JobFactory
 from pyiron_base.server.queuestatus import (
@@ -62,6 +64,7 @@ __status__ = "production"
 __date__ = "Sep 1, 2017"
 
 s = Settings()
+dbm = DatabaseManager()
 
 
 class Project(ProjectPath, HasGroups):
@@ -124,9 +127,9 @@ class Project(ProjectPath, HasGroups):
         self._data = None
         self._creator = Creator(project=self)
 
-        if not s.database_is_disabled:
-            s.open_connection()
-            self.db = s.database
+        if not dbm.database_is_disabled:
+            dbm.open_connection()
+            self.db = dbm.database
         else:
             self.db = FileTable(project=path)
         self.job_type = JobTypeChoice()
@@ -486,27 +489,9 @@ class Project(ProjectPath, HasGroups):
         )
         return folder_size / (1024 * 1024.0)
 
-    @staticmethod
-    def get_repository_status():
-        """
-        Finds the hashes for every `pyiron` module available.
-
-        Returns:
-            pandas.DataFrame: The name of each module and the hash for its current git head.
-        """
-        module_names = [name for _, name, _ in pkgutil.iter_modules() if name.startswith("pyiron")]
-
-        report = pandas.DataFrame(columns=['Module', 'Git head'], index=range(len(module_names)))
-        for i, name in enumerate(module_names):
-            try:
-                module = importlib.import_module(name)
-                repo = Repo(os.path.dirname(os.path.dirname(module.__file__)))
-                hash_ = repo.head.reference.commit.hexsha
-                report.loc[i] = [name, hash_]
-            except InvalidGitRepositoryError:
-                report.loc[i] = [name, 'Not a repo']
-
-        return report
+    @deprecate('use maintenance.get_repository_status() instead.')
+    def get_repository_status(self):
+        return self.maintenance.get_repository_status()
 
     def groups(self):
         """
@@ -1132,18 +1117,18 @@ class Project(ProjectPath, HasGroups):
         Switch from user mode to viewer mode - if viewer_mode is enable pyiron has read only access to the database.
         """
         if not isinstance(self.db, FileTable):
-            s.switch_to_viewer_mode()
-            s.open_connection()
-            self.db = s.database
+            dbm.switch_to_viewer_mode()
+            dbm.open_connection()
+            self.db = dbm.database
 
     def switch_to_user_mode(self):
         """
         Switch from viewer mode to user mode - if viewer_mode is enable pyiron has read only access to the database.
         """
         if not isinstance(self.db, FileTable):
-            s.switch_to_user_mode()
-            s.open_connection()
-            self.db = s.database
+            dbm.switch_to_user_mode()
+            dbm.open_connection()
+            self.db = dbm.database
 
     def switch_to_local_database(self, file_name="pyiron.db", cwd=None):
         """
@@ -1155,21 +1140,21 @@ class Project(ProjectPath, HasGroups):
         """
         if cwd is None:
             cwd = self.path
-        if not s.project_check_enabled:
-            s.switch_to_local_database(file_name=file_name, cwd=cwd)
+        if not dbm.project_check_enabled:
+            dbm.switch_to_local_database(file_name=file_name, cwd=cwd)
             super(Project, self).__init__(path=self.path)
         else:
-            s.switch_to_local_database(file_name=file_name, cwd=cwd)
-        self.db = s.database
+            dbm.switch_to_local_database(file_name=file_name, cwd=cwd)
+        self.db = dbm.database
 
     def switch_to_central_database(self):
         """
         Switch from local mode to central mode - if local_mode is enable pyiron is using a local database.
         """
-        s.switch_to_central_database()
-        if not s.database_is_disabled:
-            s.open_connection()
-            self.db = s.database
+        dbm.switch_to_central_database()
+        if not dbm.database_is_disabled:
+            dbm.open_connection()
+            self.db = dbm.database
         else:
             self.db = FileTable(project=self.path)
             super(Project, self).__init__(path=self.path)
@@ -1567,6 +1552,33 @@ class Maintenance:
     def global_status(self):
         return self._global
 
+    @staticmethod
+    def get_repository_status():
+
+        """
+        Finds the hashes and versions for every `pyiron` module available.
+
+        Returns:
+            pandas.DataFrame: The name of each module and the hash and version for its current git head.
+        """
+        module_names = [name for _, name, _ in pkgutil.iter_modules() if name.startswith("pyiron")]
+
+        report = pandas.DataFrame(columns=['Module', 'Git head', 'Version'], index=range(len(module_names)))
+        for i, name in enumerate(module_names):
+            module = importlib.import_module(name)
+            try:
+                repo = Repo(os.path.dirname(os.path.dirname(module.__file__)))
+                hash_ = repo.head.reference.commit.hexsha
+            except InvalidGitRepositoryError:
+                hash_ = 'Not a repo'
+            if hasattr(module, '__version__'):
+                version = module.__version__
+            else:
+                version = "not defined"
+            report.loc[i] = [name, hash_, version]
+
+        return report
+
 
 class GlobalMaintenance:
     def __init__(self):
